# -*- coding: utf-8 -*-
# Copyright © 2006 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

from gettext import gettext as _
msg0001 = _("_Language")
msg0002 = _("_Name")
msg0003 = _("_Description")
msg0004 = _("Import Template")
msg0005 = _("XML Documents")
msg0006 = _("Edit Template")
msg0007 = _("Error: Name field cannot be empty")
msg0008 = _("Error: Trigger name already in use. Please use another trigger name.")
msg0009 = _("Add Template")
msg0010 = _("Template Editor")
msg0011 = _("Error: You do not have permission to save at the location")
msg0012 = _("Error: No selection to export")
msg0013 = _("Error: File not found")
msg0014 = _("Error: Invalid template file")
msg0015 = _("Error: No template information found")
